@@ -16,8 +16,8 @@ type tt struct {
 func Test_LoadInflections(t *testing.T) {
 	r := require.New(t)
 	m := map[string]string{
-		"beatle": "the beatles",
-		"xyz":    "zyx",
+		"baby": "bebe",
+		"xyz":  "zyx",
 	}
 
 	b, err := json.Marshal(m)
@@ -33,6 +33,30 @@ func Test_LoadInflections(t *testing.T) {
 	}
 }
 
+func Test_LoadInflectionsWrongSingular(t *testing.T) {
+	r := require.New(t)
+	m := map[string]string{
+		"a file": "files",
+	}
+
+	b, err := json.Marshal(m)
+	r.NoError(err)
+
+	r.Error(LoadInflections(bytes.NewReader(b)))
+}
+
+func Test_LoadInflectionsWrongPlural(t *testing.T) {
+	r := require.New(t)
+	m := map[string]string{
+		"beatle": "the beatles",
+	}
+
+	b, err := json.Marshal(m)
+	r.NoError(err)
+
+	r.Error(LoadInflections(bytes.NewReader(b)))
+}
+
 func Test_LoadAcronyms(t *testing.T) {
 	r := require.New(t)
 	m := []string{
@@ -53,6 +77,16 @@ func Test_LoadAcronyms(t *testing.T) {
 
 var singlePluralAssertions = []tt{
 	{"", ""},
+	{"Car", "Cars"},
+	{"Boy", "Boys"},
+	{"GoodBoy", "GoodBoys"},
+	{"Axis", "Axes"},
+	{"Child", "Children"},
+	{"GoodChild", "GoodChildren"},
+	{"SmartPerson", "SmartPeople"},
+	{"SuperbOx", "SuperbOxen"},
+	{"WildOx", "WildOxen"},
+	{"wild_ox", "wild_oxen"},
 	{"ability", "abilities"},
 	{"address", "addresses"},
 	{"agency", "agencies"},
@@ -76,6 +110,7 @@ var singlePluralAssertions = []tt{
 	{"child", "children"},
 	{"circus", "circuses"},
 	{"city", "cities"},
+	{"collapse", "collapses"},
 	{"comment", "comments"},
 	{"crisis", "crises"},
 	{"criterion", "criteria"},
@@ -89,6 +124,7 @@ var singlePluralAssertions = []tt{
 	{"diagnosis_a", "diagnosis_as"},
 	{"diagnosis", "diagnoses"},
 	{"dwarf", "dwarves"},
+	{"eclipse", "eclipses"},
 	{"edge", "edges"},
 	{"elf", "elves"},
 	{"ellipsis", "ellipses"},
@@ -105,6 +141,7 @@ var singlePluralAssertions = []tt{
 	{"fox", "foxes"},
 	{"funky jeans", "funky jeans"},
 	{"fuse", "fuses"},
+	{"glimpse", "glimpses"},
 	{"goose", "geese"},
 	{"great_person", "great_people"},
 	{"half", "halves"},
@@ -115,11 +152,13 @@ var singlePluralAssertions = []tt{
 	{"index", "indices"},
 	{"information", "information"},
 	{"jeans", "jeans"},
+	{"lapse", "lapses"},
 	{"louse", "lice"},
 	{"lunch", "lunches"},
 	{"marsh", "marshes"},
 	{"matrix", "matrices"},
-	{"media", "media"},
+	{"medium", "media"},
+	{"multimedia", "multimedia"},
 	{"mouse", "mice"},
 	{"move", "moves"},
 	{"movie", "movies"},
@@ -130,6 +169,7 @@ var singlePluralAssertions = []tt{
 	{"ovum", "ova"},
 	{"ox", "oxen"},
 	{"payment_information", "payment_information"},
+	{"pepsi", "pepsis"},
 	{"person", "people"},
 	{"perspective", "perspectives"},
 	{"phenomenon", "phenomena"},
@@ -141,6 +181,7 @@ var singlePluralAssertions = []tt{
 	{"prize", "prizes"},
 	{"process", "processes"},
 	{"prometheus", "prometheuses"},
+	{"psi", "psis"},
 	{"puppy", "puppies"},
 	{"query", "queries"},
 	{"quiz", "quizzes"},
@@ -170,6 +211,7 @@ var singlePluralAssertions = []tt{
 	{"tooth", "teeth"},
 	{"truss", "trusses"},
 	{"user", "users"},
+	{"user_custom_field", "user_custom_fields"},
 	{"vedalia", "vedalias"},
 	{"virus", "viri"},
 	{"wife", "wives"},
