@@ -47,6 +47,7 @@ var singleToPlural = map[string]string{
 	"concerto":    "concertos",
 	"corpus":      "corpora",
 	"crisis":      "crises",
+	"criterion":   "criteria",
 	"curriculum":  "curriculums",
 	"datum":       "data",
 	"deer":        "deer",
@@ -56,7 +57,6 @@ var singleToPlural = map[string]string{
 	"ellipsis":    "ellipses",
 	"equipment":   "equipment",
 	"erratum":     "errata",
-	"faux pas":    "faux pas",
 	"fez":         "fezzes",
 	"fish":        "fish",
 	"focus":       "foci",
@@ -82,6 +82,7 @@ var singleToPlural = map[string]string{
 	"locus":       "loci",
 	"louse":       "lice",
 	"matrix":      "matrices",
+	"medium":      "media",
 	"minutia":     "minutiae",
 	"money":       "money",
 	"moose":       "moose",
@@ -96,6 +97,7 @@ var singleToPlural = map[string]string{
 	"ovum":        "ova",
 	"ox":          "oxen",
 	"parenthesis": "parentheses",
+	"person":      "people",
 	"phenomenon":  "phenomena",
 	"photo":       "photos",
 	"phylum":      "phyla",
@@ -157,9 +159,7 @@ type singularToPluralSuffix struct {
 }
 
 var singularToPluralSuffixList = []singularToPluralSuffix{
-	{"iterion", "iteria"},
 	{"campus", "campuses"},
-	{"genera", "genus"},
 	{"person", "people"},
 	{"phylum", "phyla"},
 	{"randum", "randa"},
@@ -169,6 +169,7 @@ var singularToPluralSuffixList = []singularToPluralSuffix{
 	{"child", "children"},
 	{"chive", "chives"},
 	{"focus", "foci"},
+	{"genus", "genera"},
 	{"hello", "hellos"},
 	{"jeans", "jeans"},
 	{"louse", "lice"},
@@ -195,7 +196,6 @@ var singularToPluralSuffixList = []singularToPluralSuffix{
 	{"oose", "eese"},
 	{"ouse", "ouses"},
 	{"ovum", "ova"},
-	{"rion", "ria"},
 	{"shoe", "shoes"},
 	{"stis", "stes"},
 	{"tive", "tives"},
@@ -225,7 +225,6 @@ var singularToPluralSuffixList = []singularToPluralSuffix{
 	{"ode", "odes"},
 	{"ofe", "oves"},
 	{"pfe", "pves"},
-	{"pse", "psis"},
 	{"qfe", "qves"},
 	{"quy", "quies"},
 	{"rfe", "rves"},
