@@ -30,28 +30,32 @@ func SingularizeWithSize(s string, i int) string {
 //	data = datum
 //	people = person
 func (i Ident) Singularize() Ident {
-	s := i.Original
+	s := i.LastPart()
 	if len(s) == 0 {
 		return i
 	}
 
 	singularMoot.RLock()
 	defer singularMoot.RUnlock()
+
 	ls := strings.ToLower(s)
 	if p, ok := pluralToSingle[ls]; ok {
-		return New(p)
+		if s == Capitalize(s) {
+			p = Capitalize(p)
+		}
+		return i.ReplaceSuffix(s, p)
 	}
 	if _, ok := singleToPlural[ls]; ok {
 		return i
 	}
 	for _, r := range singularRules {
 		if strings.HasSuffix(ls, r.suffix) {
-			return New(r.fn(s))
+			return i.ReplaceSuffix(s, r.fn(s))
 		}
 	}
 
 	if strings.HasSuffix(s, "s") {
-		return New(s[:len(s)-1])
+		return i.ReplaceSuffix("s", "")
 	}
 	return i
 }
